"""Test the colorlog.logging module."""

import logging

import colorlog


def test_logging_module(test_logger):
    test_logger(logging)


def test_colorlog_module(test_logger):
    test_logger(colorlog)


def test_colorlog_basicConfig(test_logger):
    colorlog.basicConfig()
    test_logger(colorlog.getLogger())



"""Test that `from colorlog import *` works correctly."""

from colorlog import *  # noqa


def test_exports():
    assert {
        'ColoredFormatter', 'default_log_colors', 'escape_codes',
        'basicConfig', 'root', 'getLogger', 'debug', 'info', 'warning',
        'error', 'exception', 'critical', 'log', 'exception'
    } < set(globals())
